import { DownOutlined } from '@ant-design/icons';
import { useContext } from '@antv/gi-sdk';
import Graphin, { Behaviors } from '@antv/graphin';
import { Dropdown, Empty, Menu, message, Tooltip, Upload } from 'antd';
import React, { useEffect, useMemo, useRef } from 'react';
import Util from '../utils';
import './index.less';
import FormattedMessage, { formatMessage } from './locale';
import { formatData } from './util';
var exportGraphData = Util.exportGraphData;
var ClickSelect = Behaviors.ClickSelect;
var PatternPane = function PatternPane(_ref) {
  var id = _ref.id,
    data = _ref.data,
    schemaEdgeMap = _ref.schemaEdgeMap,
    editPattern = _ref.editPattern,
    extractPattern = _ref.extractPattern,
    importData = _ref.importData;
  var _a, _b, _c, _d;
  var _useContext = useContext(),
    config = _useContext.config;
  var graphRef = useRef();
  // 数据发生变化，fitView
  useEffect(function () {
    var _a;
    var graph = (_a = graphRef === null || graphRef === void 0 ? void 0 : graphRef.current) === null || _a === void 0 ? void 0 : _a.graph;
    if (graph && !graph.destroyed) {
      graph.fitView();
      graph.get('canvas').set('localRefresh', false);
    }
  }, [data]);
  useEffect(function () {
    var _a;
    var graph = (_a = graphRef === null || graphRef === void 0 ? void 0 : graphRef.current) === null || _a === void 0 ? void 0 : _a.graph;
    if (graph && !graph.destroyed) {
      graph.changeSize(456, 246);
    }
  }, [(_b = (_a = graphRef === null || graphRef === void 0 ? void 0 : graphRef.current) === null || _a === void 0 ? void 0 : _a.graph) === null || _b === void 0 ? void 0 : _b.get('width'), (_d = (_c = graphRef === null || graphRef === void 0 ? void 0 : graphRef.current) === null || _c === void 0 ? void 0 : _c.graph) === null || _d === void 0 ? void 0 : _d.get('height')]);
  /**
   * 下载模式数据到本地 json 文件，方便下次上传
   */
  var downloadPatternData = function downloadPatternData() {
    var _a;
    var graph = (_a = graphRef === null || graphRef === void 0 ? void 0 : graphRef.current) === null || _a === void 0 ? void 0 : _a.graph;
    if (graph && !graph.destroyed) {
      exportGraphData(graph.save(), 'pattern-data');
    }
  };
  /**
   * 导入 json 图数据
   * @param result
   * @returns
   */
  var importPattern = function importPattern(result) {
    var fileInfo = result.file;
    var _ref2 = fileInfo || {},
      status = _ref2.status,
      type = _ref2.type,
      name = _ref2.name,
      file = _ref2.originFileObj;
    if (status !== 'uploading') {
      return;
    }
    if (type === 'json' || name.includes('.json')) {
      var fReader = new FileReader();
      fReader.onload = function () {
        if (typeof fReader.result === 'string') {
          var _data = JSON.parse(fReader.result);
          importData === null || importData === void 0 ? void 0 : importData(_data, id);
        }
      };
      fReader.readAsText(file);
    } else {
      message.error(formatMessage({
        id: '请上传 JSON 格式的数据'
      }));
    }
  };
  var buildPatternMenuItems = [/*#__PURE__*/React.createElement(Menu.Item, {
    onClick: function onClick() {
      return editPattern === null || editPattern === void 0 ? void 0 : editPattern(id);
    }
  }, /*#__PURE__*/React.createElement(FormattedMessage, {
    id: "edit-pattern"
  })), /*#__PURE__*/React.createElement(Menu.Item, {
    onClick: function onClick() {
      return extractPattern === null || extractPattern === void 0 ? void 0 : extractPattern(id);
    }
  }, /*#__PURE__*/React.createElement(Tooltip, {
    title: /*#__PURE__*/React.createElement(FormattedMessage, {
      id: "extract-pattern-tip"
    })
  }, /*#__PURE__*/React.createElement(FormattedMessage, {
    id: "extract-pattern"
  }))), /*#__PURE__*/React.createElement(Menu.Item, null, /*#__PURE__*/React.createElement(Upload, {
    accept: ".json,.txt",
    onChange: importPattern,
    fileList: []
  }, /*#__PURE__*/React.createElement(FormattedMessage, {
    id: "import-pattern"
  })))];
  var modifyPatternMenuItems = buildPatternMenuItems.concat( /*#__PURE__*/React.createElement(Menu.Item, {
    onClick: downloadPatternData
  }, /*#__PURE__*/React.createElement(FormattedMessage, {
    id: "download-pattern"
  })));
  var buildPatternMenu = /*#__PURE__*/React.createElement(Menu, null, buildPatternMenuItems);
  var modifyPatternMenu = /*#__PURE__*/React.createElement(Menu, null, modifyPatternMenuItems);
  var graphData = useMemo(function () {
    return data ? formatData(data, config, schemaEdgeMap) : {
      nodes: [],
      edges: []
    };
  }, [data]);
  return /*#__PURE__*/React.createElement("div", {
    className: "kg-pattern-pane-content"
  }, data ? /*#__PURE__*/React.createElement("div", {
    className: "kg-pattern-pane-graph"
  }, /*#__PURE__*/React.createElement(Dropdown, {
    overlay: modifyPatternMenu,
    className: "kg-pattern-pane-edit"
  }, /*#__PURE__*/React.createElement("a", {
    onClick: function onClick(e) {
      return e.preventDefault();
    }
  }, /*#__PURE__*/React.createElement(FormattedMessage, {
    id: "build-pattern"
  }), " ", /*#__PURE__*/React.createElement(DownOutlined, null))), /*#__PURE__*/React.createElement(Graphin, {
    width: 388,
    height: 246,
    data: graphData,
    ref: graphRef,
    animate: false,
    minZoom: 0.001,
    fitView: true
  }, /*#__PURE__*/React.createElement(ClickSelect, {
    disabled: true
  }))) : /*#__PURE__*/React.createElement(Empty, {
    className: "kg-pattern-empty",
    image: Empty.PRESENTED_IMAGE_SIMPLE,
    description: /*#__PURE__*/React.createElement("span", null, /*#__PURE__*/React.createElement(FormattedMessage, {
      id: "no-pattern"
    }), "\xA0\xA0", /*#__PURE__*/React.createElement(Dropdown, {
      overlay: buildPatternMenu
    }, /*#__PURE__*/React.createElement("a", {
      onClick: function onClick(e) {
        return e.preventDefault();
      }
    }, /*#__PURE__*/React.createElement(FormattedMessage, {
      id: "build-pattern"
    }), " ", /*#__PURE__*/React.createElement(DownOutlined, null))))
  }));
};
export default PatternPane;